<?php

namespace app\admin\controller\article\courseresource;
use app\common\controller\Backend;
use fast\Tree;
use think\Db;
use think\Exception;
use think\exception\PDOException;
use think\exception\ValidateException;
use app\admin\model\CourseClassModel;

/**课程资源分类
 * Class
 */
class Courseresourceclass extends Backend
{

    /**
     * 分类模型对象
     * @var
     */
    protected $model = null;
    protected $classlist=array();
    public function _initialize()
    {
        parent::_initialize();
        $this->model = new CourseClassModel();

        // 必须将结果集转换为数组
        $cateList = collection($this->model->alias('gc')->order('orderby', 'asc')->field('gc.*')
            ->where("FIND_IN_SET(4,pidexist)")->select())->toArray();
        Tree::instance()->init($cateList,'pid');
        $this->classlist = Tree::instance()->getTreeList(Tree::instance()->getTreeArray(0), 'title');
        $classdata = [0 => __('None')];
        foreach ($this->classlist as $k => &$v)
        {
            $classdata[$v['id']] = $v['title'];
        }
        $this->view->assign("classdata", $classdata);
        $this->view->assign('statusList',$this->model->getStatusList());

    }

    /**
     * 查看
     */
    public function index()
    {
        if ($this->request->isAjax())
        {
            $list = $this->classlist;
            foreach ($list as $key => &$val){
                $val['title'] = html_entity_decode($val['title']);
                $val['admin']= Db::name("admin")->where(['id'=>$val['auth_id']])->find();
            }
            $total = count($this->classlist);

            $result = array("total" => $total, "rows" => $list);

            return json($result);
        }
        return $this->view->fetch();
    }

    /**
     * 添加
     */
    public function add()
    {
        if ($this->request->isPost()) {
            $params = $this->request->post("row/a");
            if ($params) {
                $params = $this->preExcludeFields($params);
                if ($this->dataLimit && $this->dataLimitFieldAutoFill) {
                    $params[$this->dataLimitField] = $this->auth->id;
                }
                $params = $this->preExcludeFields($params);
                $params['auth_id']=$this->auth->id;
                $params['createtime']=time();
                if(empty($params['pid'])){
                    $this->error(__('请选择分类', ''));
                }
                //是否采用模型验证
                if ($this->modelValidate) {
                    $name = str_replace("\\model\\", "\\validate\\", get_class($this->model));
                    $validate = is_bool($this->modelValidate) ? ($this->modelSceneValidate ? $name . '.edit' : $name) : $this->modelValidate;
                    $this->model->validateFailException(true)->validate($validate);
                }
                $result = $this->model->allowField(true)->save($params);
                $getLastInsID=$this->model->getLastInsID();
                $result = addClass($params['pid'],$getLastInsID);
                if ($result !== false) {
                    $this->success();
                }else{
                    $this->error(__('操作添加失败', ''));
                }
            }
            $this->error(__('Parameter %s can not be empty', ''));
        }
        return $this->view->fetch();
    }



    /**
     * 编辑
     */
    public function edit($ids = null)
    {
        $row = $this->model->get($ids);
        if (!$row) {
            $this->error(__('No Results were found'));
        }
        $adminIds = $this->getDataLimitAdminIds();
        if (is_array($adminIds)) {
            if (!in_array($row[$this->dataLimitField], $adminIds)) {
                $this->error(__('You have no permission'));
            }
        }
        if ($this->request->isPost()) {
            $params = $this->request->post("row/a");
            if ($params) {
                $params = $this->preExcludeFields($params);
                $result = false;
                Db::startTrans();
                try {
                    //是否采用模型验证
                    if ($this->modelValidate) {
                        $name = str_replace("\\model\\", "\\validate\\", get_class($this->model));
                        $validate = is_bool($this->modelValidate) ? ($this->modelSceneValidate ? $name . '.edit' : $name) : $this->modelValidate;
                        $row->validateFailException(true)->validate($validate);
                    }
                    if(empty($params['pid'])){
                        $this->error(__('请选择分类', ''));
                    }
                    if ($params['pid'] != $row['pid']) {
                        $childrenIds = Tree::instance()->init(collection(Db::name("course_class")->where("FIND_IN_SET(4,pidexist)")->select())->toArray())->getChildrenIds($row['id']);
                        if (in_array($params['pid'], $childrenIds)) {
                            return ['code'=>-1,'msg'=>'Can not change the parent to child'];
                        }
                    }
                    $params['pidexist']=editClass($params,$row);
                    $result = $row->allowField(true)->save($params);
                    Db::commit();
                } catch (ValidateException $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                } catch (PDOException $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                } catch (Exception $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                }
                if ($result !== false) {
                    $this->success();
                } else {
                    $this->error(__('No rows were updated'));
                }
            }
            $this->error(__('Parameter %s can not be empty', ''));
        }
        $this->view->assign("row", $row);
        return $this->view->fetch();
    }


    /**
     * 读取分类
     */
    public function courseresourceSelsected()
    {
        $keyField = $this->request->request("keyField");
        $keyValue = $this->request->request("keyValue");
        // 必须将结果集转换为数组
        if($keyValue){
            $list = collection($this->model->alias('gc')->order('orderby', 'asc')->field('gc.*')
                ->where(["$keyField"=>$keyValue])->where("FIND_IN_SET(4,pidexist)")->select())->toArray();
        }else {
            $cateList = collection($this->model->alias('gc')->order('orderby', 'asc')->field('gc.*')
                ->where("FIND_IN_SET(4,pidexist)")->select())->toArray();
            Tree::instance()->init($cateList,'pid');
            $list = Tree::instance()->getTreeList(Tree::instance()->getTreeArray(0), 'title');
        }
        $classdata = [0 => __('None')];
        foreach ($list as $key => &$val){
            $classdata[$val['id']] = $val['title'];
            $val['title'] = html_entity_decode($val['title']);
            $val['admin']= Db::name("admin")->where(['id'=>$val['auth_id']])->find();
        }
        $result = array("rows" => $list);
        return json($result);
    }

}