<?php
namespace app\admin\controller\video\course;

use app\admin\model\CourseVideoModel;
use app\common\controller\Backend;
use fast\Tree;
use think\Db;
use think\Exception;
use think\exception\PDOException;
use think\exception\ValidateException;

/**视频课程
 * Class Coursevideo
 */
class Coursevideo extends Backend
{
    /**
     * 文章模型对象
     * @var
     */
    protected $model = null;

    public function _initialize()
    {
        parent::_initialize();
        $this->model = new CourseVideoModel();
        $this->view->assign('statusList',$this->model->getStatusList());
        $this->view->assign('indexTypeList',$this->model->getIndexTypeList());


    }
    /**
     * 查看
     */
    public function index()
    {
        //设置过滤方法
        $this->request->filter(['strip_tags']);
        if ($this->request->isAjax()) {
            //如果发送的来源是Selectpage，则转发到Selectpage
            if ($this->request->request('keyField')) {
                return $this->selectpage();
            }
            $this->relationSearch = true;
            list($where, $sort, $order, $offset, $limit) = $this->buildparams();
            $total = $this->model
                ->where($where)
                ->order($sort, $order)
                ->count();
            $list = $this->model->with('admin,course')
                ->where($where)
                ->order($sort, $order)
                ->limit($offset, $limit)
                ->select();
            $list = collection($list)->toArray();
            foreach ($list as $key=>$val){
                $list[$key]['introduction']=mb_substr_content($val['introduction'],55);
            }
            $result = array("total" => $total, "rows" => $list);
            return json($result);
        }
        return $this->view->fetch();
    }


    /**
     * 添加
     */
    public function add()
    {
        if ($this->request->isPost()) {
            $params = $this->request->post("row/a");
            if ($params) {
                $params = $this->preExcludeFields($params);
                if ($this->dataLimit && $this->dataLimitFieldAutoFill) {
                    $params[$this->dataLimitField] = $this->auth->id;
                }
                $params = $this->preExcludeFields($params);
                $params['auth_id']=$this->auth->id;
                $params['createtime']=time();
                //是否采用模型验证
                if ($this->modelValidate) {
                    $name = str_replace("\\model\\", "\\validate\\", get_class($this->model));
                    $validate = is_bool($this->modelValidate) ? ($this->modelSceneValidate ? $name . '.edit' : $name) : $this->modelValidate;
                    $this->model->validateFailException(true)->validate($validate);
                }
                $result = $this->model->allowField(true)->save($params);
                if ($result !== false) {
                    $this->success();
                }else{
                    $this->error(__('操作添加失败', ''));
                }
            }
            $this->error(__('Parameter %s can not be empty', ''));
        }
        return $this->view->fetch();
    }



    /**
     * 编辑
     */
    public function edit($ids = null)
    {
        $row = $this->model->get($ids);
        if (!$row) {
            $this->error(__('No Results were found'));
        }
        $adminIds = $this->getDataLimitAdminIds();
        if (is_array($adminIds)) {
            if (!in_array($row[$this->dataLimitField], $adminIds)) {
                $this->error(__('You have no permission'));
            }
        }
        if ($this->request->isPost()) {
            $params = $this->request->post("row/a");
            if ($params) {
                $params = $this->preExcludeFields($params);
                $result = false;
                Db::startTrans();
                try {
                    //是否采用模型验证
                    if ($this->modelValidate) {
                        $name = str_replace("\\model\\", "\\validate\\", get_class($this->model));
                        $validate = is_bool($this->modelValidate) ? ($this->modelSceneValidate ? $name . '.edit' : $name) : $this->modelValidate;
                        $row->validateFailException(true)->validate($validate);
                    }
                    $result = $row->allowField(true)->save($params);
                    Db::commit();
                } catch (ValidateException $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                } catch (PDOException $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                } catch (Exception $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                }
                if ($result !== false) {
                    $this->success();
                } else {
                    $this->error(__('No rows were updated'));
                }
            }
            $this->error(__('Parameter %s can not be empty', ''));
        }
        $this->view->assign("row", $row);
        return $this->view->fetch();
    }



    /**
     * 读取分类
     */
    public function classSelsected()
    {
        $keyField = $this->request->request("keyField");
        $keyValue = $this->request->request("keyValue");
        // 必须将结果集转换为数组
        if($keyValue){
            $list = collection(Db::name("course_class")->alias('gc')->order('orderby', 'asc')->field('gc.*')
                ->where(["$keyField"=>$keyValue])->select())->toArray();
        }else {
            $cateList = collection(Db::name("course_class")->alias('gc')->order('orderby', 'asc')->field('gc.*')
               ->select())->toArray();
            Tree::instance()->init($cateList,'pid');
            $list = Tree::instance()->getTreeList(Tree::instance()->getTreeArray(0), 'title');
        }
        $classdata = [0 => __('None')];
        foreach ($list as $key => &$val){
            $classdata[$val['id']] = $val['title'];
            $val['title'] = html_entity_decode($val['title']);
            $val['admin']= Db::name("admin")->where(['id'=>$val['auth_id']])->find();
        }
        $result = array("rows" => $list);
        return json($result);
    }


    public function detail($ids){
        $row = $this->model->get(['id' => $ids]);
        if (!$row) {
            $this->error(__('No Results were found'));
        }
        $this->view->assign("row", $row);
        return $this->view->fetch();
    }

}